@@ -79,9 +79,21 @@ GstElementDetails gst_filesrc_details = {
   "(C) 1999",
 };
 
+#define DEFAULT_BLOCKSIZE 	4*1024
+#define DEFAULT_MMAPSIZE 	4*1024*1024
+
+#ifdef G_HAVE_ISO_VARARGS
+
+/* #define fs_print(...) g_print(__VA_ARGS__)  */
+#define fs_print(...)
+
+#elif defined(G_HAVE_GNUC_VARARGS)
+
 /* #define fs_print(format,args...) g_print(format, ## args)  */
 #define fs_print(format,args...)
 
+#endif
+
 /* FileSrc signals and args */
 enum {
   /* FILL ME */
@@ -90,16 +102,14 @@ enum {
 
 enum {
   ARG_0,
-  ARG_OFFSET,
   ARG_LOCATION,
-  ARG_FILESIZE,
   ARG_FD,
   ARG_BLOCKSIZE,
-  ARG_MAPSIZE,
+  ARG_MMAPSIZE,
   ARG_TOUCH,
 };
 
-GST_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
+GST_PAD_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
   { GST_EVENT_SEEK, GST_SEEK_METHOD_CUR | 
 	  	    GST_SEEK_METHOD_SET | 
 		    GST_SEEK_METHOD_END | 
@@ -109,11 +119,11 @@ GST_EVENT_MASK_FUNCTION (gst_filesrc_get_event_mask,
 )
 
 GST_PAD_QUERY_TYPE_FUNCTION (gst_filesrc_get_query_types,
-  GST_PAD_QUERY_TOTAL,
-  GST_PAD_QUERY_POSITION
+  GST_QUERY_TOTAL,
+  GST_QUERY_POSITION
 )
 
-GST_FORMATS_FUNCTION (gst_filesrc_get_formats,
+GST_PAD_FORMATS_FUNCTION (gst_filesrc_get_formats,
   GST_FORMAT_BYTES
 )
 
@@ -128,7 +138,7 @@ static void		gst_filesrc_get_property	(GObject *object, guint prop_id,
 
 static GstBuffer *	gst_filesrc_get			(GstPad *pad);
 static gboolean 	gst_filesrc_srcpad_event 	(GstPad *pad, GstEvent *event);
-static gboolean 	gst_filesrc_srcpad_query 	(GstPad *pad, GstPadQueryType type,
+static gboolean 	gst_filesrc_srcpad_query 	(GstPad *pad, GstQueryType type,
 		         				 GstFormat *format, gint64 *value);
 
 static GstElementStateReturn	gst_filesrc_change_state	(GstElement *element);
@@ -169,16 +179,23 @@ gst_filesrc_class_init (GstFileSrcClass *klass)
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
-  gst_element_class_install_std_props (
-	  GST_ELEMENT_CLASS (klass),
-	  "fd",           ARG_FD,           G_PARAM_READABLE,
-	  "offset",       ARG_OFFSET,       G_PARAM_READWRITE,
-	  "filesize",     ARG_FILESIZE,     G_PARAM_READABLE,
-	  "location",     ARG_LOCATION,     G_PARAM_READWRITE,
-	  "blocksize",    ARG_BLOCKSIZE,    G_PARAM_READWRITE,
-	  "mmapsize",     ARG_MAPSIZE,      G_PARAM_READWRITE,
-	  "touch",        ARG_TOUCH,        G_PARAM_READWRITE,
-	  NULL);
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_FD,
+    g_param_spec_int ("fd", "File-descriptor", "File-descriptor for the file being mmap()d",
+                      0, G_MAXINT, 0, G_PARAM_READABLE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LOCATION,
+    g_param_spec_string ("location", "File Location", "Location of the file to read",
+                         NULL, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_BLOCKSIZE,
+    g_param_spec_ulong ("blocksize", "Block size", "Size in bytes to read per buffer",
+                        1, G_MAXULONG, DEFAULT_BLOCKSIZE, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_MMAPSIZE,
+    g_param_spec_ulong ("mmapsize", "mmap() Block Size",
+                        "Size in bytes of mmap()d regions",
+                        0, G_MAXULONG, DEFAULT_MMAPSIZE, G_PARAM_READWRITE));
+  g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_TOUCH,
+    g_param_spec_boolean ("touch", "Touch read data",
+                          "Touch data to force disk read", 
+			  FALSE, G_PARAM_READWRITE));
 
   gobject_class->dispose 	= gst_filesrc_dispose;
   gobject_class->set_property 	= gst_filesrc_set_property;
@@ -219,11 +236,11 @@ gst_filesrc_init (GstFileSrc *src)
   src->filelen = 0;
 
   src->curoffset = 0;
-  src->block_size = 4096;
-  src->touch = TRUE;
+  src->block_size = DEFAULT_BLOCKSIZE;
+  src->touch = FALSE;
 
   src->mapbuf = NULL;
-  src->mapsize = 4 * 1024 * 1024;		/* default is 4MB */
+  src->mapsize = DEFAULT_MMAPSIZE;		/* default is 4MB */
 
   src->map_regions = g_tree_new (gst_filesrc_bufcmp);
   src->map_regions_lock = g_mutex_new();
@@ -277,16 +294,13 @@ gst_filesrc_set_property (GObject *object, guint prop_id, const GValue *value, G
       src->block_size = g_value_get_ulong (value);
       g_object_notify (G_OBJECT (src), "blocksize");
       break;
-    case ARG_OFFSET:
-      src->curoffset = g_value_get_int64 (value);
-      g_object_notify (G_OBJECT (src), "offset");
-      break;
-    case ARG_MAPSIZE:
+    case ARG_MMAPSIZE:
       if ((src->mapsize % src->pagesize) == 0) {
         src->mapsize = g_value_get_ulong (value);
         g_object_notify (G_OBJECT (src), "mmapsize");
       } else {
-        GST_INFO(0, "invalid mapsize, must a multiple of pagesize, which is %d\n",src->pagesize);
+        GST_INFO (0, "invalid mapsize, must a multiple of pagesize, which is %d", 
+	          src->pagesize);
       }
       break;
     case ARG_TOUCH:
@@ -312,19 +326,13 @@ gst_filesrc_get_property (GObject *object, guint prop_id, GValue *value, GParamS
     case ARG_LOCATION:
       g_value_set_string (value, src->filename);
       break;
-    case ARG_FILESIZE:
-      g_value_set_int64 (value, src->filelen);
-      break;
     case ARG_FD:
       g_value_set_int (value, src->fd);
       break;
     case ARG_BLOCKSIZE:
       g_value_set_ulong (value, src->block_size);
       break;
-    case ARG_OFFSET:
-      g_value_set_int64 (value, src->curoffset);
-      break;
-    case ARG_MAPSIZE:
+    case ARG_MMAPSIZE:
       g_value_set_ulong (value, src->mapsize);
       break;
     case ARG_TOUCH:
@@ -339,25 +347,32 @@ gst_filesrc_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 static void
 gst_filesrc_free_parent_mmap (GstBuffer *buf)
 {
-  GstFileSrc *src = GST_FILESRC(GST_BUFFER_POOL_PRIVATE(buf));
+  GstFileSrc *src = GST_FILESRC (GST_BUFFER_POOL_PRIVATE (buf));
 
-  fs_print ("freeing mmap()d buffer at %d+%d\n",GST_BUFFER_OFFSET(buf),GST_BUFFER_SIZE(buf));
+  fs_print ("freeing mmap()d buffer at %d+%d\n", 
+	    GST_BUFFER_OFFSET (buf), GST_BUFFER_SIZE (buf));
 
   /* remove the buffer from the list of available mmap'd regions */
-  g_mutex_lock(src->map_regions_lock);
-  g_tree_remove(src->map_regions,buf);
+  g_mutex_lock (src->map_regions_lock);
+  g_tree_remove (src->map_regions, buf);
   /* check to see if the tree is empty */
-  if (g_tree_nnodes(src->map_regions) == 0) {
+  if (g_tree_nnodes (src->map_regions) == 0) {
     /* we have to free the bufferpool we don't have yet */
   }
-  g_mutex_unlock(src->map_regions_lock);
+  g_mutex_unlock (src->map_regions_lock);
 
 #ifdef MADV_DONTNEED
   /* madvise to tell the kernel what to do with it */
-  madvise(GST_BUFFER_DATA(buf),GST_BUFFER_SIZE(buf),MADV_DONTNEED);
+  madvise (GST_BUFFER_DATA (buf), GST_BUFFER_SIZE (buf), MADV_DONTNEED);
 #endif
   /* now unmap the memory */
-  munmap(GST_BUFFER_DATA(buf),GST_BUFFER_MAXSIZE(buf));
+  munmap (GST_BUFFER_DATA (buf), GST_BUFFER_MAXSIZE (buf));
+  /* cast to unsigned long, since there's no gportable way to print
+   * guint64 as hex */
+  GST_DEBUG (0, "unmapped region %08lx+%08lx at %p", 
+		  (unsigned long) GST_BUFFER_OFFSET (buf),
+		  (unsigned long) GST_BUFFER_MAXSIZE (buf), 
+		  GST_BUFFER_DATA (buf));
 
   GST_BUFFER_DATA (buf) = NULL;
 
@@ -369,38 +384,47 @@ gst_filesrc_map_region (GstFileSrc *src, off_t offset, size_t size)
 {
   GstBuffer *buf;
   gint retval;
+  void *mmapregion;
 
   g_return_val_if_fail (offset >= 0, NULL);
 
   fs_print  ("mapping region %08llx+%08x from file into memory\n",offset,size);
+  mmapregion = mmap (NULL, size, PROT_READ, MAP_SHARED, src->fd, offset);
 
-  /* time to allocate a new mapbuf */
-  buf = gst_buffer_new();
-  /* mmap() the data into this new buffer */
-  GST_BUFFER_DATA(buf) = mmap (NULL, size, PROT_READ, MAP_SHARED, src->fd, offset);
-  if (GST_BUFFER_DATA(buf) == NULL) {
+  if (mmapregion == NULL) {
     gst_element_error (GST_ELEMENT (src), "couldn't map file");
-  } else if (GST_BUFFER_DATA(buf) == MAP_FAILED) {
+    return NULL;
+  }
+  else if (mmapregion == MAP_FAILED) {
     gst_element_error (GST_ELEMENT (src), "mmap (0x%x, %d, 0x%llx) : %s",
  	     size, src->fd, offset, strerror (errno));
+    return NULL;
   }
+  GST_DEBUG (0, "mapped region %08lx+%08lx from file into memory at %p", 
+		  (unsigned long)offset, (unsigned long)size, mmapregion);
+
+  /* time to allocate a new mapbuf */
+  buf = gst_buffer_new ();
+  /* mmap() the data into this new buffer */
+  GST_BUFFER_DATA (buf) = mmapregion;
+
 #ifdef MADV_SEQUENTIAL
   /* madvise to tell the kernel what to do with it */
-  retval = madvise(GST_BUFFER_DATA(buf),GST_BUFFER_SIZE(buf),MADV_SEQUENTIAL);
+  retval = madvise (GST_BUFFER_DATA (buf), GST_BUFFER_SIZE (buf), MADV_SEQUENTIAL);
 #endif
   /* fill in the rest of the fields */
-  GST_BUFFER_FLAG_SET(buf, GST_BUFFER_READONLY);
-  GST_BUFFER_FLAG_SET(buf, GST_BUFFER_ORIGINAL);
-  GST_BUFFER_SIZE(buf) = size;
-  GST_BUFFER_MAXSIZE(buf) = size;
-  GST_BUFFER_OFFSET(buf) = offset;
-  GST_BUFFER_TIMESTAMP(buf) = -1LL;
-  GST_BUFFER_POOL_PRIVATE(buf) = src;
-  GST_BUFFER_FREE_FUNC(buf) = (GstDataFreeFunction) gst_filesrc_free_parent_mmap;
+  GST_BUFFER_FLAG_SET (buf, GST_BUFFER_READONLY);
+  GST_BUFFER_FLAG_SET (buf, GST_BUFFER_ORIGINAL);
+  GST_BUFFER_SIZE (buf) = size;
+  GST_BUFFER_MAXSIZE (buf) = size;
+  GST_BUFFER_OFFSET (buf) = offset;
+  GST_BUFFER_TIMESTAMP (buf) = GST_CLOCK_TIME_NONE;
+  GST_BUFFER_POOL_PRIVATE (buf) = src;
+  GST_BUFFER_FREE_FUNC (buf) = (GstDataFreeFunction) gst_filesrc_free_parent_mmap;
 
-  g_mutex_lock(src->map_regions_lock);
-  g_tree_insert(src->map_regions,buf,buf);
-  g_mutex_unlock(src->map_regions_lock);
+  g_mutex_lock (src->map_regions_lock);
+  g_tree_insert (src->map_regions,buf,buf);
+  g_mutex_unlock (src->map_regions_lock);
 
   return buf;
 }
@@ -422,6 +446,9 @@ gst_filesrc_map_small_region (GstFileSrc *src, off_t offset, size_t size)
     mapsize = ((size + mod + src->pagesize - 1) / src->pagesize) * src->pagesize;
 /*    printf("not on page boundaries, resizing map to %d+%d\n",mapbase,mapsize);*/
     map = gst_filesrc_map_region(src, mapbase, mapsize);
+    if (map == NULL)
+      return NULL;
+
     ret = gst_buffer_create_sub (map, offset - mapbase, size);
 
     gst_buffer_unref (map);
@@ -476,22 +503,22 @@ gst_filesrc_get (GstPad *pad)
     GstEvent *event;
 
     src->seek_happened = FALSE;
-    GST_DEBUG (GST_CAT_EVENT, "filesrc sending discont\n");
+    GST_DEBUG (GST_CAT_EVENT, "filesrc sending discont");
     event = gst_event_new_discontinuous (FALSE, GST_FORMAT_BYTES, src->curoffset, NULL);
-    GST_EVENT_DISCONT_NEW_MEDIA (event) = FALSE;
     src->need_flush = FALSE;
     return GST_BUFFER (event);
   }
   /* check for flush */
   if (src->need_flush) {
     src->need_flush = FALSE;
-    GST_DEBUG (GST_CAT_EVENT, "filesrc sending flush\n");
+    GST_DEBUG (GST_CAT_EVENT, "filesrc sending flush");
     return GST_BUFFER (gst_event_new_flush ());
   }
 
   /* check for EOF */
   if (src->curoffset == src->filelen) {
-    GST_DEBUG (0, "filesrc eos %lld %lld\n", src->curoffset, src->filelen);
+    GST_DEBUG (0, "filesrc eos %" G_GINT64_FORMAT
+		  " %" G_GINT64_FORMAT, src->curoffset, src->filelen);
     gst_element_set_eos (GST_ELEMENT (src));
     return GST_BUFFER (gst_event_new (GST_EVENT_EOS));
   }
@@ -508,6 +535,10 @@ gst_filesrc_get (GstPad *pad)
     readend = src->curoffset + readsize;
   }
 
+  GST_DEBUG (0, "attempting to read %08lx, %08lx, %08lx, %08lx", 
+		  (unsigned long)readsize, (unsigned long)readend,
+		  (unsigned long)mapstart, (unsigned long)mapend);
+
   /* if the start is past the mapstart */
   if (src->curoffset >= mapstart) {
     /* if the end is before the mapend, the buffer is in current mmap region... */
@@ -523,6 +554,8 @@ gst_filesrc_get (GstPad *pad)
       fs_print ("read buf %llu+%d starts in mapbuf %d+%d but ends outside, creating new mmap\n",
              src->curoffset,readsize,GST_BUFFER_OFFSET(src->mapbuf),GST_BUFFER_SIZE(src->mapbuf));
       buf = gst_filesrc_map_small_region (src, src->curoffset, readsize);
+      if (buf == NULL)
+        return NULL;
     }
 
     /* the only other option is that buffer is totally outside, which means we search for it */
@@ -536,6 +569,8 @@ gst_filesrc_get (GstPad *pad)
     fs_print ("read buf %llu+%d starts before mapbuf %d+%d, but overlaps it\n",
              src->curoffset,readsize,GST_BUFFER_OFFSET(src->mapbuf),GST_BUFFER_SIZE(src->mapbuf));
     buf = gst_filesrc_map_small_region (src, src->curoffset, readsize);
+    if (buf == NULL)
+      return NULL;
   }
 
   /* then deal with the case where the read buffer is totally outside */
@@ -560,6 +595,8 @@ gst_filesrc_get (GstPad *pad)
         fs_print ("read buf %llu+%d crosses a %d-byte boundary, creating a one-off\n",
                src->curoffset,readsize,src->mapsize);
         buf = gst_filesrc_map_small_region (src, src->curoffset, readsize);
+	if (buf == NULL)
+          return NULL;
 
       /* otherwise we will create a new mmap region and set it to the default */
       } else {
@@ -579,6 +616,9 @@ gst_filesrc_get (GstPad *pad)
 	}
         /* create a new one */
         src->mapbuf = gst_filesrc_map_region (src, nextmap, mapsize);
+	if (src->mapbuf == NULL)
+          return NULL;
+
         /* subbuffer it */
         buf = gst_buffer_create_sub (src->mapbuf, src->curoffset - nextmap, readsize);
       }
@@ -588,13 +628,13 @@ gst_filesrc_get (GstPad *pad)
   /* if we need to touch the buffer (to bring it into memory), do so */
   if (src->touch) {
     volatile guchar *p = GST_BUFFER_DATA (buf), c;
-    for (i=0;i<GST_BUFFER_SIZE(buf);i+=src->pagesize)
+
+    for (i=0; i < GST_BUFFER_SIZE (buf); i += src->pagesize)
       c = p[i];
   }
 
   /* we're done, return the buffer */
   src->curoffset += GST_BUFFER_SIZE(buf);
-  g_object_notify (G_OBJECT (src), "offset");
   return buf;
 }
 
@@ -631,15 +671,11 @@ gst_filesrc_open_file (GstFileSrc *src)
 
     /* allocate the first mmap'd region */
     src->mapbuf = gst_filesrc_map_region (src, 0, src->mapsize);
+    if (src->mapbuf == NULL)
+      return FALSE;
 
     src->curoffset = 0;
 
-    /* now notify of the changes */
-    g_object_freeze_notify (G_OBJECT (src));
-    g_object_notify (G_OBJECT (src), "filesize");
-    g_object_notify (G_OBJECT (src), "offset");
-    g_object_thaw_notify (G_OBJECT (src));
-
     GST_FLAG_SET (src, GST_FILESRC_OPEN);
   }
   return TRUE;
@@ -658,14 +694,11 @@ gst_filesrc_close_file (GstFileSrc *src)
   src->fd = 0;
   src->filelen = 0;
   src->curoffset = 0;
-  /* and notify that things changed */
-  g_object_freeze_notify (G_OBJECT (src));
-  g_object_notify (G_OBJECT (src), "filesize");
-  g_object_notify (G_OBJECT (src), "offset");
-  g_object_thaw_notify (G_OBJECT (src));
 
-  if (src->mapbuf)
+  if (src->mapbuf) {
     gst_buffer_unref (src->mapbuf);
+    src->mapbuf = NULL;
+  }
 
   GST_FLAG_UNSET (src, GST_FILESRC_OPEN);
 }
@@ -703,23 +736,31 @@ gst_filesrc_change_state (GstElement *element)
 }
 
 static gboolean
-gst_filesrc_srcpad_query (GstPad *pad, GstPadQueryType type,
+gst_filesrc_srcpad_query (GstPad *pad, GstQueryType type,
 		          GstFormat *format, gint64 *value)
 {
   GstFileSrc *src = GST_FILESRC (GST_PAD_PARENT (pad));
 
   switch (type) {
-    case GST_PAD_QUERY_TOTAL:
+    case GST_QUERY_TOTAL:
       if (*format != GST_FORMAT_BYTES) {
 	return FALSE;
       }
       *value = src->filelen;
       break;
-    case GST_PAD_QUERY_POSITION:
-      if (*format != GST_FORMAT_BYTES) {
-	return FALSE;
+    case GST_QUERY_POSITION:
+      switch (*format) {
+	case GST_FORMAT_BYTES:
+          *value = src->curoffset;
+          break;
+	case GST_FORMAT_PERCENT:
+	  if (src->filelen == 0)
+	    return FALSE;
+          *value = src->curoffset * GST_FORMAT_PERCENT_MAX / src->filelen;
+          break;
+        default:
+	  return FALSE;
       }
-      *value = src->curoffset;
       break;
     default:
       return FALSE;
@@ -751,25 +792,24 @@ gst_filesrc_srcpad_event (GstPad *pad, GstEvent *event)
           if (offset > src->filelen) 
 	    goto error;
           src->curoffset = offset;
-          GST_DEBUG(0, "seek set pending to %lld", src->curoffset);
+          GST_DEBUG(0, "seek set pending to %" G_GINT64_FORMAT, src->curoffset);
 	  break;
         case GST_SEEK_METHOD_CUR:
           if (offset + src->curoffset > src->filelen) 
 	    goto error;
           src->curoffset += offset;
-          GST_DEBUG(0, "seek cur pending to %lld", src->curoffset);
+          GST_DEBUG(0, "seek cur pending to %" G_GINT64_FORMAT, src->curoffset);
 	  break;
         case GST_SEEK_METHOD_END:
           if (ABS (offset) > src->filelen) 
 	    goto error;
           src->curoffset = src->filelen - ABS (offset);
-          GST_DEBUG(0, "seek end pending to %lld", src->curoffset);
+          GST_DEBUG(0, "seek end pending to %" G_GINT64_FORMAT, src->curoffset);
 	  break;
 	default:
           goto error;
 	  break;
       }
-      g_object_notify (G_OBJECT (src), "offset");  
       src->seek_happened = TRUE;
       src->need_flush = GST_EVENT_SEEK_FLAGS(event) & GST_SEEK_FLAG_FLUSH;
       break;
