@@ -70,7 +70,9 @@ debug_log_handler (const gchar *log_domain,
 		   gpointer user_data)
 {
   g_log_default_handler (log_domain, log_level, message, user_data);
-  g_on_error_query (NULL);
+  /* FIXME: do we still need this ? fatal errors these days are all
+   * other than core errors */
+  /* g_on_error_query (NULL); */
 }
 
 enum {
@@ -140,8 +142,9 @@ gst_init_get_popt_table (void)
  * This function will return %FALSE if GStreamer could not be initialized
  * for some reason.  If you want your program to fail fatally,
  * use gst_init() instead.
+ *
+ * Returns: TRUE if GStreamer coul be initialized
  */
-
 gboolean
 gst_init_check (int *argc, char **argv[])
 {
@@ -176,6 +179,8 @@ gst_init (int *argc, char **argv[])
  * Initializes the GStreamer library, parsing the options,
  * setting up internal path lists,
  * registering built-in elements, and loading standard plugins.
+ *
+ * Returns: TRUE when the initialization succeeded.
  */
 gboolean
 gst_init_with_popt_table (int *argc, char **argv[],
@@ -185,19 +190,59 @@ gst_init_with_popt_table (int *argc, char **argv[],
   gint nextopt, i, j, nstrip;
   gchar **temp;
   const struct poptOption *options;
-  /* this is probably hacky, no? */
-  const struct poptOption options_with[] = {
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, poptHelpOptions, 				 0, "Help options:", NULL},
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (struct poptOption *) gst_init_get_popt_table(), 0, "GStreamer options:", NULL},
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (struct poptOption *) popt_options, 		 0, "Application options:", NULL},
-    POPT_TABLEEND
+  struct poptOption options_with[] = {
+     POPT_TABLEEND,
+     POPT_TABLEEND,
+     POPT_TABLEEND,
+     POPT_TABLEEND
   };
-  const struct poptOption options_without[] = {
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, poptHelpOptions, 				 0, "Help options:", NULL},
-    {NULL, NUL, POPT_ARG_INCLUDE_TABLE, (struct poptOption *) gst_init_get_popt_table(), 0, "GStreamer options:", NULL},
-    POPT_TABLEEND
+  struct poptOption options_without[] = {
+     POPT_TABLEEND,
+     POPT_TABLEEND,
+     POPT_TABLEEND
   };
 
+  /* This used to be done by struct initialization, but most
+   * compilers don't like calling functions in a struct
+   * initialization.  (It's a GCC extension.)  FIXME: This should
+   * be reworked to look better. */
+  options_with[0].longName   = NULL;
+  options_with[0].shortName  = NUL;
+  options_with[0].argInfo    = POPT_ARG_INCLUDE_TABLE;
+  options_with[0].arg        = poptHelpOptions;
+  options_with[0].val        = 0;
+  options_with[0].descrip    = "Help options:";
+  options_with[0].argDescrip = NULL;
+  options_with[1].longName   = NULL;
+  options_with[1].shortName  = NUL;
+  options_with[1].argInfo    = POPT_ARG_INCLUDE_TABLE;
+  options_with[1].arg        = (struct poptOption *) gst_init_get_popt_table();
+  options_with[1].val        = 0;
+  options_with[1].descrip    = "GStreamer options:";
+  options_with[1].argDescrip = NULL;
+  options_with[2].longName   = NULL;
+  options_with[2].shortName  = NUL;
+  options_with[2].argInfo    = POPT_ARG_INCLUDE_TABLE;
+  options_with[2].arg        = (struct poptOption *) popt_options;
+  options_with[2].val        = 0;
+  options_with[2].descrip    = "Application options:";
+  options_with[2].argDescrip = NULL;
+
+  options_without[0].longName   = NULL;
+  options_without[0].shortName  = NUL;
+  options_without[0].argInfo    = POPT_ARG_INCLUDE_TABLE;
+  options_without[0].arg        = poptHelpOptions;
+  options_without[0].val        = 0;
+  options_without[0].descrip    = "Help options:";
+  options_without[0].argDescrip = NULL;
+  options_without[1].longName   = NULL;
+  options_without[1].shortName  = NUL;
+  options_without[1].argInfo    = POPT_ARG_INCLUDE_TABLE;
+  options_without[1].arg        = (struct poptOption *) gst_init_get_popt_table();
+  options_without[1].val        = 0;
+  options_without[1].descrip    = "GStreamer options:";
+  options_without[1].argDescrip = NULL;
+
   if (gst_initialized)
   {
     GST_DEBUG (GST_CAT_GST_INIT, "already initialized gst\n");
@@ -341,7 +386,7 @@ init_pre (void)
   gst_registry_add_path (_global_registry, PLUGINS_BUILDDIR "/gst/types");
   gst_registry_add_path (_global_registry, PLUGINS_BUILDDIR "/gst/autoplug");
   gst_registry_add_path (_global_registry, PLUGINS_BUILDDIR "/gst/schedulers");
-  gst_registry_add_path (_global_registry, PLUGINS_BUILDDIR "/gst/caches");
+  gst_registry_add_path (_global_registry, PLUGINS_BUILDDIR "/gst/indexers");
 #else
   /* add the main (installed) library path */
   gst_registry_add_path (_global_registry, PLUGINS_DIR);
@@ -436,6 +481,7 @@ init_post (void)
             GST_VERSION, _gst_use_threads?"":"(no threads)");
   
   _gst_format_initialize ();
+  _gst_query_type_initialize ();
   gst_object_get_type ();
   gst_pad_get_type ();
   gst_real_pad_get_type ();
@@ -448,7 +494,8 @@ init_post (void)
 #ifndef GST_DISABLE_AUTOPLUG
   gst_autoplug_factory_get_type ();
 #endif
-  gst_cache_factory_get_type ();
+  gst_index_factory_get_type ();
+  gst_uri_handler_get_type ();
 
 
   plugin_path = g_getenv ("GST_PLUGIN_PATH");
