@@ -112,11 +112,11 @@ typedef struct _GstGhostPadClass GstGhostPadClass;
 
 
 typedef enum {
-  GST_PAD_CONNECT_REFUSED = -1,
-  GST_PAD_CONNECT_DELAYED =  0,
-  GST_PAD_CONNECT_OK      =  1,
-  GST_PAD_CONNECT_DONE    =  2
-} GstPadConnectReturn;
+  GST_PAD_LINK_REFUSED = -1,
+  GST_PAD_LINK_DELAYED =  0,
+  GST_PAD_LINK_OK      =  1,
+  GST_PAD_LINK_DONE    =  2
+} GstPadLinkReturn;
 
 /* convenience functions */
 #ifdef G_HAVE_ISO_VARARGS
@@ -141,12 +141,13 @@ typedef gboolean		(*GstPadConvertFunction)	(GstPad *pad,
 								 GstFormat *dest_format, gint64 *dest_value);
 typedef gboolean		(*GstPadQueryFunction)		(GstPad *pad, GstQueryType type,
 		 						 GstFormat *format, gint64  *value);
-typedef GList*			(*GstPadIntConnFunction)	(GstPad *pad);
+typedef GList*			(*GstPadIntLinkFunction)	(GstPad *pad);
 typedef const GstFormat*	(*GstPadFormatsFunction)	(GstPad *pad);
 typedef const GstEventMask*	(*GstPadEventMaskFunction)	(GstPad *pad);
 typedef const GstQueryType*	(*GstPadQueryTypeFunction)	(GstPad *pad);
 
-typedef GstPadConnectReturn	(*GstPadConnectFunction) 	(GstPad *pad, GstCaps *caps);
+typedef GstPadLinkReturn	(*GstPadLinkFunction) 		(GstPad *pad, GstCaps *caps);
+typedef void			(*GstPadUnlinkFunction) 	(GstPad *pad);
 typedef GstCaps*		(*GstPadGetCapsFunction) 	(GstPad *pad, GstCaps *caps);
 typedef GstBufferPool*		(*GstPadBufferPoolFunction) 	(GstPad *pad);
 
@@ -188,7 +189,8 @@ struct _GstRealPad {
   
   GstPadDirection 		 direction;
 
-  GstPadConnectFunction 	 connectfunc;
+  GstPadLinkFunction 		 linkfunc;
+  GstPadUnlinkFunction 		 unlinkfunc;
   GstRealPad 			*peer;
 
   gpointer 			 sched_private;
@@ -209,7 +211,7 @@ struct _GstRealPad {
   GstPadQueryFunction		 queryfunc;
   GstPadFormatsFunction		 formatsfunc;
   GstPadQueryTypeFunction	 querytypefunc;
-  GstPadIntConnFunction		 intconnfunc;
+  GstPadIntLinkFunction		 intlinkfunc;
 
   GstPadBufferPoolFunction 	 bufferpoolfunc;
 
@@ -221,8 +223,8 @@ struct _GstRealPadClass {
 
   /* signal callbacks */
   void (*caps_nego_failed)	(GstPad *pad);
-  void (*connected)		(GstPad *pad, GstPad *peer);
-  void (*disconnected)		(GstPad *pad, GstPad *peer);
+  void (*linked)		(GstPad *pad, GstPad *peer);
+  void (*unlinked)		(GstPad *pad, GstPad *peer);
 };
 
 struct _GstGhostPad {
@@ -257,12 +259,13 @@ struct _GstGhostPadClass {
 #define GST_RPAD_EVENTHANDLER(pad)	(((GstRealPad *)(pad))->eventhandler)
 #define GST_RPAD_CONVERTFUNC(pad)	(((GstRealPad *)(pad))->convertfunc)
 #define GST_RPAD_QUERYFUNC(pad)		(((GstRealPad *)(pad))->queryfunc)
-#define GST_RPAD_INTCONNFUNC(pad)	(((GstRealPad *)(pad))->intconnfunc)
+#define GST_RPAD_INTLINKFUNC(pad)	(((GstRealPad *)(pad))->intlinkfunc)
 #define GST_RPAD_FORMATSFUNC(pad)	(((GstRealPad *)(pad))->formatsfunc)
 #define GST_RPAD_QUERYTYPEFUNC(pad)	(((GstRealPad *)(pad))->querytypefunc)
 #define GST_RPAD_EVENTMASKFUNC(pad)	(((GstRealPad *)(pad))->eventmaskfunc)
 
-#define GST_RPAD_CONNECTFUNC(pad)	(((GstRealPad *)(pad))->connectfunc)
+#define GST_RPAD_LINKFUNC(pad)		(((GstRealPad *)(pad))->linkfunc)
+#define GST_RPAD_UNLINKFUNC(pad)	(((GstRealPad *)(pad))->unlinkfunc)
 #define GST_RPAD_GETCAPSFUNC(pad)	(((GstRealPad *)(pad))->getcapsfunc)
 #define GST_RPAD_BUFFERPOOLFUNC(pad)	(((GstRealPad *)(pad))->bufferpoolfunc)
 
@@ -276,9 +279,9 @@ struct _GstGhostPadClass {
 #define GST_PAD_PEER(pad)		GST_PAD_CAST(GST_RPAD_PEER(GST_PAD_REALIZE(pad)))
 
 /* Some check functions (unused?) */
-#define GST_PAD_IS_CONNECTED(pad)	(GST_PAD_PEER(pad) != NULL)
+#define GST_PAD_IS_LINKED(pad)		(GST_PAD_PEER(pad) != NULL)
 #define GST_PAD_IS_ACTIVE(pad)		(!GST_FLAG_IS_SET(GST_PAD_REALIZE(pad), GST_PAD_DISABLED))
-#define GST_PAD_IS_USABLE(pad)		(GST_PAD_IS_CONNECTED (pad) && \
+#define GST_PAD_IS_USABLE(pad)		(GST_PAD_IS_LINKED (pad) && \
 		                         GST_PAD_IS_ACTIVE(pad) && GST_PAD_IS_ACTIVE(GST_PAD_PEER (pad)))
 #define GST_PAD_CAN_PULL(pad)		(GST_IS_REAL_PAD(pad) && GST_REAL_PAD(pad)->gethandler != NULL)
 #define GST_PAD_IS_SRC(pad)		(GST_PAD_DIRECTION(pad) == GST_PAD_SRC)
@@ -301,22 +304,26 @@ typedef enum {
 #define GST_PAD_TEMPLATE_DIRECTION(templ)	(((GstPadTemplate *)(templ))->direction)
 #define GST_PAD_TEMPLATE_PRESENCE(templ)	(((GstPadTemplate *)(templ))->presence)
 #define GST_PAD_TEMPLATE_CAPS(templ)		(((GstPadTemplate *)(templ))->caps)
-#define GST_PAD_TEMPLATE_FIXED(templ)		(((GstPadTemplate *)(templ))->fixed)
 
-#define GST_PAD_TEMPLATE_IS_FIXED(templ)	(GST_PAD_TEMPLATE_FIXED(templ) == TRUE)
+typedef enum {
+  GST_PAD_TEMPLATE_FIXED        = GST_OBJECT_FLAG_LAST,
+	    
+  GST_PAD_TEMPLATE_FLAG_LAST    = GST_OBJECT_FLAG_LAST + 4
+} GstPadTemplateFlags;
+
+#define GST_PAD_TEMPLATE_IS_FIXED(templ)        (GST_FLAG_IS_SET(templ), GST_PAD_TEMPLATE_FIXED)
 
 struct _GstPadTemplate {
-  GstObject	  object;
+  GstObject	   object;
 
   gchar           *name_template;
-  GstPadDirection direction;
-  GstPadPresence  presence;
+  GstPadDirection  direction;
+  GstPadPresence   presence;
   GstCaps	  *caps;
-  gboolean	  fixed;
 };
 
 struct _GstPadTemplateClass {
-  GstObjectClass parent_class;
+  GstObjectClass   parent_class;
 
   /* signal callbacks */
   void (*pad_created)	(GstPadTemplate *templ, GstPad *pad);
@@ -418,28 +425,29 @@ void			gst_pad_set_event_mask_function		(GstPad *pad, GstPadEventMaskFunction ma
 const GstEventMask*	gst_pad_get_event_masks			(GstPad *pad);
 const GstEventMask*	gst_pad_get_event_masks_default		(GstPad *pad);
 
-/* pad connections */
-void			gst_pad_set_connect_function		(GstPad *pad, GstPadConnectFunction connect);
-gboolean                gst_pad_can_connect            		(GstPad *srcpad, GstPad *sinkpad);
-gboolean                gst_pad_can_connect_filtered   		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
+/* pad links */
+void			gst_pad_set_link_function		(GstPad *pad, GstPadLinkFunction link);
+gboolean                gst_pad_can_link            		(GstPad *srcpad, GstPad *sinkpad);
+gboolean                gst_pad_can_link_filtered   		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
+void			gst_pad_set_unlink_function		(GstPad *pad, GstPadUnlinkFunction link);
 
-gboolean                gst_pad_connect             		(GstPad *srcpad, GstPad *sinkpad);
-gboolean                gst_pad_connect_filtered       		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
-void			gst_pad_disconnect			(GstPad *srcpad, GstPad *sinkpad);
+gboolean                gst_pad_link             		(GstPad *srcpad, GstPad *sinkpad);
+gboolean                gst_pad_link_filtered       		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
+void			gst_pad_unlink				(GstPad *srcpad, GstPad *sinkpad);
 
 GstPad*			gst_pad_get_peer			(GstPad *pad);
 
 /* capsnego functions */
 GstCaps*		gst_pad_get_caps			(GstPad *pad);
 GstCaps*		gst_pad_get_pad_template_caps		(GstPad *pad);
-GstPadConnectReturn	gst_pad_try_set_caps			(GstPad *pad, GstCaps *caps);
+GstPadLinkReturn	gst_pad_try_set_caps			(GstPad *pad, GstCaps *caps);
 gboolean		gst_pad_check_compatibility		(GstPad *srcpad, GstPad *sinkpad);
 
 void			gst_pad_set_getcaps_function		(GstPad *pad, GstPadGetCapsFunction getcaps);
-GstPadConnectReturn     gst_pad_proxy_connect          		(GstPad *pad, GstCaps *caps);
-gboolean		gst_pad_reconnect_filtered		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
+GstPadLinkReturn	gst_pad_proxy_link          		(GstPad *pad, GstCaps *caps);
+gboolean		gst_pad_relink_filtered			(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
 gboolean		gst_pad_perform_negotiate		(GstPad *srcpad, GstPad *sinkpad);
-gboolean		gst_pad_try_reconnect_filtered		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
+gboolean		gst_pad_try_relink_filtered		(GstPad *srcpad, GstPad *sinkpad, GstCaps *filtercaps);
 GstCaps*	     	gst_pad_get_allowed_caps       		(GstPad *pad);
 gboolean	     	gst_pad_recalc_allowed_caps    		(GstPad *pad);
 
@@ -475,9 +483,9 @@ gboolean		gst_pad_query				(GstPad *pad, GstQueryType type,
 gboolean 		gst_pad_query_default 			(GstPad *pad, GstQueryType type,
 		                      				 GstFormat *format, gint64 *value);
 
-void			gst_pad_set_internal_connection_function(GstPad *pad, GstPadIntConnFunction intconn);
-GList*			gst_pad_get_internal_connections	(GstPad *pad);
-GList*	 		gst_pad_get_internal_connections_default (GstPad *pad);
+void			gst_pad_set_internal_link_function	(GstPad *pad, GstPadIntLinkFunction intlink);
+GList*			gst_pad_get_internal_links		(GstPad *pad);
+GList*	 		gst_pad_get_internal_links_default 	(GstPad *pad);
 	
 /* misc helper functions */
 gboolean 		gst_pad_dispatcher 			(GstPad *pad, GstPadDispatcherFunction dispatch, 
@@ -489,7 +497,7 @@ gboolean 		gst_pad_dispatcher 			(GstPad *pad, GstPadDispatcherFunction dispatch
 			(gst_probe_dispatcher_remove_probe (&(GST_REAL_PAD (pad)-probedisp), probe))
 
 #ifndef GST_DISABLE_LOADSAVE
-void			gst_pad_load_and_connect		(xmlNodePtr self, GstObject *parent);
+void			gst_pad_load_and_link			(xmlNodePtr self, GstObject *parent);
 #endif
 
 
