@@ -29,6 +29,7 @@
 
 static void 	gst_scheduler_class_init 	(GstSchedulerClass *klass);
 static void 	gst_scheduler_init 		(GstScheduler *sched);
+static void 	gst_scheduler_dispose 		(GObject *object);
 
 static GstObjectClass *parent_class = NULL;
 
@@ -62,7 +63,13 @@ gst_scheduler_get_type (void)
 static void
 gst_scheduler_class_init (GstSchedulerClass *klass)
 {
+  GObjectClass *gobject_class;
+      
+  gobject_class = (GObjectClass*) klass;
+      
   parent_class = g_type_class_ref (GST_TYPE_OBJECT);
+
+  gobject_class->dispose = GST_DEBUG_FUNCPTR (gst_scheduler_dispose);
 }
 
 static void
@@ -77,6 +84,24 @@ gst_scheduler_init (GstScheduler *sched)
   sched->clock = NULL;
 }
 
+static void
+gst_scheduler_dispose (GObject *object)
+{
+  GstScheduler *sched = GST_SCHEDULER (object);
+
+  /* thse lists should all be NULL */
+  GST_DEBUG (0, "scheduler %p dispose %p %p %p",
+		  object,
+		  sched->clock_providers,
+		  sched->clock_receivers,
+		  sched->schedulers);
+
+  gst_object_swap ((GstObject **)&sched->current_clock, NULL);
+  gst_object_swap ((GstObject **)&sched->clock, NULL);
+
+  G_OBJECT_CLASS (parent_class)->dispose (object);
+}
+
 /**
  * gst_scheduler_setup:
  * @sched: the scheduler
@@ -116,15 +141,15 @@ gst_scheduler_reset (GstScheduler *sched)
 }
 
 /**
- * gst_scheduler_pad_connect:
+ * gst_scheduler_pad_link:
  * @sched: the scheduler
- * @srcpad: the srcpad to connect
- * @sinkpad: the sinkpad to connect to
+ * @srcpad: the srcpad to link
+ * @sinkpad: the sinkpad to link to
  *
- * Connect the srcpad to the given sinkpad.
+ * Links the srcpad to the given sinkpad.
  */
 void
-gst_scheduler_pad_connect (GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad)
+gst_scheduler_pad_link (GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad)
 {
   GstSchedulerClass *sclass;
 
@@ -134,20 +159,20 @@ gst_scheduler_pad_connect (GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad)
 
   sclass = GST_SCHEDULER_GET_CLASS (sched);
 
-  if (sclass->pad_connect)
-    sclass->pad_connect (sched, srcpad, sinkpad);
+  if (sclass->pad_link)
+    sclass->pad_link (sched, srcpad, sinkpad);
 }
 
 /**
- * gst_scheduler_pad_disconnect:
+ * gst_scheduler_pad_unlink:
  * @sched: the scheduler
- * @srcpad: the srcpad to disconnect
- * @sinkpad: the sinkpad to disconnect from
+ * @srcpad: the srcpad to unlink
+ * @sinkpad: the sinkpad to unlink from
  *
- * Disconnect the srcpad to the given sinkpad.
+ * Unlinks the srcpad from the given sinkpad.
  */
 void
-gst_scheduler_pad_disconnect (GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad)
+gst_scheduler_pad_unlink (GstScheduler *sched, GstPad *srcpad, GstPad *sinkpad)
 {
   GstSchedulerClass *sclass;
 
@@ -157,8 +182,8 @@ gst_scheduler_pad_disconnect (GstScheduler *sched, GstPad *srcpad, GstPad *sinkp
 
   sclass = GST_SCHEDULER_GET_CLASS (sched);
 
-  if (sclass->pad_disconnect)
-    sclass->pad_disconnect (sched, srcpad, sinkpad);
+  if (sclass->pad_unlink)
+    sclass->pad_unlink (sched, srcpad, sinkpad);
 }
 
 /**
@@ -274,7 +299,6 @@ gst_scheduler_state_transition (GstScheduler *sched, GstElement *element, gint t
   g_return_val_if_fail (GST_IS_ELEMENT (element), GST_STATE_FAILURE);
 
   if (element == sched->parent && sched->parent_sched == NULL) {
-
     switch (transition) {
       case GST_STATE_READY_TO_PAUSED:
       {
@@ -286,7 +310,7 @@ gst_scheduler_state_transition (GstScheduler *sched, GstElement *element, gint t
         GST_DEBUG (GST_CAT_CLOCK, "scheduler READY to PAUSED clock is %p (%s)", clock, 
 			(clock ? GST_OBJECT_NAME (clock) : "nil"));
 
-	sched->current_clock = clock;
+        gst_object_swap ((GstObject **)&sched->current_clock, (GstObject *)clock);
         break;
       }
       case GST_STATE_PAUSED_TO_PLAYING:
@@ -296,7 +320,7 @@ gst_scheduler_state_transition (GstScheduler *sched, GstElement *element, gint t
         GST_DEBUG (GST_CAT_CLOCK, "scheduler PAUSED to PLAYING clock is %p (%s)", clock, 
 			(clock ? GST_OBJECT_NAME (clock) : "nil"));
 
-	sched->current_clock = clock;
+        gst_object_swap ((GstObject **)&sched->current_clock, (GstObject *)clock);
 
 	gst_scheduler_set_clock (sched, sched->current_clock);
         if (sched->current_clock) {
@@ -361,6 +385,12 @@ gst_scheduler_add_scheduler (GstScheduler *sched, GstScheduler *sched2)
 
   g_return_if_fail (GST_IS_SCHEDULER (sched));
   g_return_if_fail (GST_IS_SCHEDULER (sched2));
+  g_return_if_fail (sched2->parent_sched == NULL);
+
+  GST_DEBUG (0,"gstscheduler: %p add scheduler %p", sched, sched2);
+
+  gst_object_ref (GST_OBJECT (sched2));
+  gst_object_ref (GST_OBJECT (sched));
 
   sched->schedulers = g_list_prepend (sched->schedulers, sched2);
   sched2->parent_sched = sched;
@@ -385,14 +415,20 @@ gst_scheduler_remove_scheduler (GstScheduler *sched, GstScheduler *sched2)
 
   g_return_if_fail (GST_IS_SCHEDULER (sched));
   g_return_if_fail (GST_IS_SCHEDULER (sched2));
+  g_return_if_fail (sched2->parent_sched == sched);
 
-  sched->schedulers = g_list_remove (sched->schedulers, sched2);
-  sched2->parent_sched = NULL;
+  GST_DEBUG (0,"gstscheduler: %p remove scheduler %p", sched, sched2);
 
   sclass = GST_SCHEDULER_GET_CLASS (sched);
 
   if (sclass->remove_scheduler)
     sclass->remove_scheduler (sched, sched2);
+
+  sched->schedulers = g_list_remove (sched->schedulers, sched2);
+  sched2->parent_sched = NULL;
+
+  gst_object_unref (GST_OBJECT (sched2));
+  gst_object_unref (GST_OBJECT (sched));
 }
 
 /**
@@ -464,19 +500,24 @@ gst_scheduler_error (GstScheduler *sched, GstElement *element)
  * @element: the element requesting a yield
  *
  * Tell the scheduler to schedule another element.
+ *
+ * Returns: TRUE if the element should save its state, FALSE
+ * if the scheduler can perform this action itself.
  */
-void
+gboolean
 gst_scheduler_yield (GstScheduler *sched, GstElement *element)
 {
   GstSchedulerClass *sclass;
 
-  g_return_if_fail (GST_IS_SCHEDULER (sched));
-  g_return_if_fail (GST_IS_ELEMENT (element));
+  g_return_val_if_fail (GST_IS_SCHEDULER (sched), TRUE);
+  g_return_val_if_fail (GST_IS_ELEMENT (element), TRUE);
 
   sclass = GST_SCHEDULER_GET_CLASS (sched);
 
   if (sclass->yield)
-    sclass->yield (sched, element);
+    return sclass->yield (sched, element);
+
+  return TRUE;
 }
 
 /**
@@ -572,7 +613,8 @@ gst_scheduler_use_clock (GstScheduler *sched, GstClock *clock)
   g_return_if_fail (GST_IS_SCHEDULER (sched));
 
   GST_FLAG_SET (sched, GST_SCHEDULER_FLAG_FIXED_CLOCK);
-  sched->clock = clock;
+
+  gst_object_swap ((GstObject **)&sched->clock, (GstObject *)clock);
 
   GST_DEBUG (GST_CAT_CLOCK, "scheduler using fixed clock %p (%s)", clock, 
 		(clock ? GST_OBJECT_NAME (clock) : "nil"));
@@ -598,7 +640,7 @@ gst_scheduler_set_clock (GstScheduler *sched, GstClock *clock)
   receivers = sched->clock_receivers;
   schedulers = sched->schedulers;
 
-  sched->current_clock = clock;
+  gst_object_swap ((GstObject **)&sched->current_clock, (GstObject *)clock);
 
   while (receivers) {
     GstElement *element = GST_ELEMENT (receivers->data);
@@ -632,7 +674,8 @@ gst_scheduler_auto_clock (GstScheduler *sched)
   g_return_if_fail (GST_IS_SCHEDULER (sched));
 
   GST_FLAG_UNSET (sched, GST_SCHEDULER_FLAG_FIXED_CLOCK);
-  sched->clock = NULL;
+
+  gst_object_swap ((GstObject **)&sched->clock, NULL);
 
   GST_DEBUG (GST_CAT_CLOCK, "scheduler using automatic clock");
 }
@@ -783,15 +826,18 @@ gst_scheduler_factory_new (const gchar *name, const gchar *longdesc, GType type)
 {
   GstSchedulerFactory *factory;
 
-  g_return_val_if_fail(name != NULL, NULL);
+  g_return_val_if_fail (name != NULL, NULL);
+
   factory = gst_scheduler_factory_find (name);
+
   if (!factory) {
     factory = GST_SCHEDULER_FACTORY (g_object_new (GST_TYPE_SCHEDULER_FACTORY, NULL));
+    GST_PLUGIN_FEATURE_NAME (factory) = g_strdup (name);
+  }
+  else {
+    g_free (factory->longdesc);
   }
 
-  GST_PLUGIN_FEATURE_NAME (factory) = g_strdup (name);
-  if (factory->longdesc)
-    g_free (factory->longdesc);
   factory->longdesc = g_strdup (longdesc);
   factory->type = type;
 
@@ -825,11 +871,12 @@ gst_scheduler_factory_find (const gchar *name)
 {
   GstPluginFeature *feature;
 
-  g_return_val_if_fail(name != NULL, NULL);
+  g_return_val_if_fail (name != NULL, NULL);
 
   GST_DEBUG (0,"gstscheduler: find \"%s\"", name);
 
   feature = gst_registry_pool_find_feature (name, GST_TYPE_SCHEDULER_FACTORY);
+
   if (feature)
     return GST_SCHEDULER_FACTORY (feature);
 
@@ -853,7 +900,8 @@ gst_scheduler_factory_create (GstSchedulerFactory *factory, GstElement *parent)
   GstScheduler *new = NULL;
 
   g_return_val_if_fail (factory != NULL, NULL);
-  g_return_val_if_fail (parent != NULL, NULL);
+  g_return_val_if_fail (GST_IS_ELEMENT (parent), NULL);
+  g_return_val_if_fail (GST_ELEMENT_SCHED (parent) == NULL, NULL);
 
   if (gst_plugin_feature_ensure_loaded (GST_PLUGIN_FEATURE (factory))) {
     g_return_val_if_fail (factory->type != 0, NULL);
@@ -915,8 +963,7 @@ gst_scheduler_factory_make (const gchar *name, GstElement *parent)
 void
 gst_scheduler_factory_set_default_name (const gchar* name)
 {
-  if (_default_name)
-    g_free (_default_name);
+  g_free (_default_name);
 
   _default_name = g_strdup (name);
 }
