@@ -31,11 +31,27 @@
 #endif
 #define G_LOG_DOMAIN "Cothreads"
 
+#ifdef G_HAVE_ISO_VARARGS
+
+#ifdef COTHREADS_DEBUG_ENABLED
+#define COTHREADS_DEBUG(...) \
+  { \
+     fprintf(stderr, __VA_ARGS__); \
+     fprintf(stderr, "\n"); \
+  }
+#else
+#define COTHREADS_DEBUG(...)
+#endif
+
+#elif defined(G_HAVE_GNUC_VARARGS)
+
 #ifdef COTHREADS_DEBUG_ENABLED
 #define COTHREADS_DEBUG(text, args...) fprintf(stderr, text "\n", ##args)
 #else
 #define COTHREADS_DEBUG(text, args...)
 #endif
 
+#endif
+
 
 #endif /* __COTHREADS_PRIVATE_H__ */
